@@ -1,4 +1,4 @@
-/* Copyright (C) 2001-2012 Artifex Software, Inc.
+/* Copyright (C) 2001-2018 Artifex Software, Inc.
    All Rights Reserved.
 
    This software is provided AS-IS with no warranty, either express or
@@ -9,14 +9,16 @@
    of the license contained in the file LICENSE in this distribution.
 
    Refer to licensing information at http://www.artifex.com or contact
-   Artifex Software, Inc.,  7 Mt. Lassen Drive - Suite A-134, San Rafael,
-   CA  94903, U.S.A., +1(415)492-9861, for further information.
+   Artifex Software, Inc.,  1305 Grant Avenue - Suite 200, Novato,
+   CA 94945, U.S.A., +1(415)492-9861, for further information.
 */
 
 /*
     jbig2dec
 */
 
+#ifndef _JBIG2_ARITH_H
+#define _JBIG2_ARITH_H
 
 typedef struct _Jbig2ArithState Jbig2ArithState;
 
@@ -26,13 +28,12 @@ typedef struct _Jbig2ArithState Jbig2ArithState;
 typedef unsigned char Jbig2ArithCx;
 
 /* allocate and initialize a new arithmetic coding state */
-Jbig2ArithState *
-jbig2_arith_new (Jbig2Ctx *ctx, Jbig2WordStream *ws);
+Jbig2ArithState *jbig2_arith_new(Jbig2Ctx *ctx, Jbig2WordStream *ws);
 
 /* decode a bit */
-bool
-jbig2_arith_decode (Jbig2ArithState *as, Jbig2ArithCx *pcx);
+bool jbig2_arith_decode(Jbig2ArithState *as, Jbig2ArithCx *pcx, int *code);
 
 /* returns true if the end of the data stream has been reached (for sanity checks) */
-bool
-jbig2_arith_has_reached_marker(Jbig2ArithState *as);
+bool jbig2_arith_has_reached_marker(Jbig2ArithState *as);
+
+#endif /* _JBIG2_ARITH_H */
